# coding: utf-8

"""
    validateapi

    The validation APIs help you validate data. Check if an E-mail address is real. Check if a domain is real. Check up on an IP address, and even where it is located. All this and much more is available in the validation API.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class LeadEnrichmentResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'successful': 'bool',
        'lead_type': 'str',
        'contact_business_email': 'str',
        'contact_first_name': 'str',
        'contact_last_name': 'str',
        'contact_gender': 'str',
        'company_name': 'str',
        'company_domain_name': 'str',
        'company_house_number': 'str',
        'company_street': 'str',
        'company_city': 'str',
        'company_state_or_province': 'str',
        'company_postal_code': 'str',
        'company_country': 'str',
        'company_country_code': 'str',
        'company_telephone': 'str',
        'company_vat_number': 'str',
        'employee_count': 'int'
    }

    attribute_map = {
        'successful': 'Successful',
        'lead_type': 'LeadType',
        'contact_business_email': 'ContactBusinessEmail',
        'contact_first_name': 'ContactFirstName',
        'contact_last_name': 'ContactLastName',
        'contact_gender': 'ContactGender',
        'company_name': 'CompanyName',
        'company_domain_name': 'CompanyDomainName',
        'company_house_number': 'CompanyHouseNumber',
        'company_street': 'CompanyStreet',
        'company_city': 'CompanyCity',
        'company_state_or_province': 'CompanyStateOrProvince',
        'company_postal_code': 'CompanyPostalCode',
        'company_country': 'CompanyCountry',
        'company_country_code': 'CompanyCountryCode',
        'company_telephone': 'CompanyTelephone',
        'company_vat_number': 'CompanyVATNumber',
        'employee_count': 'EmployeeCount'
    }

    def __init__(self, successful=None, lead_type=None, contact_business_email=None, contact_first_name=None, contact_last_name=None, contact_gender=None, company_name=None, company_domain_name=None, company_house_number=None, company_street=None, company_city=None, company_state_or_province=None, company_postal_code=None, company_country=None, company_country_code=None, company_telephone=None, company_vat_number=None, employee_count=None):  # noqa: E501
        """LeadEnrichmentResponse - a model defined in Swagger"""  # noqa: E501

        self._successful = None
        self._lead_type = None
        self._contact_business_email = None
        self._contact_first_name = None
        self._contact_last_name = None
        self._contact_gender = None
        self._company_name = None
        self._company_domain_name = None
        self._company_house_number = None
        self._company_street = None
        self._company_city = None
        self._company_state_or_province = None
        self._company_postal_code = None
        self._company_country = None
        self._company_country_code = None
        self._company_telephone = None
        self._company_vat_number = None
        self._employee_count = None
        self.discriminator = None

        if successful is not None:
            self.successful = successful
        if lead_type is not None:
            self.lead_type = lead_type
        if contact_business_email is not None:
            self.contact_business_email = contact_business_email
        if contact_first_name is not None:
            self.contact_first_name = contact_first_name
        if contact_last_name is not None:
            self.contact_last_name = contact_last_name
        if contact_gender is not None:
            self.contact_gender = contact_gender
        if company_name is not None:
            self.company_name = company_name
        if company_domain_name is not None:
            self.company_domain_name = company_domain_name
        if company_house_number is not None:
            self.company_house_number = company_house_number
        if company_street is not None:
            self.company_street = company_street
        if company_city is not None:
            self.company_city = company_city
        if company_state_or_province is not None:
            self.company_state_or_province = company_state_or_province
        if company_postal_code is not None:
            self.company_postal_code = company_postal_code
        if company_country is not None:
            self.company_country = company_country
        if company_country_code is not None:
            self.company_country_code = company_country_code
        if company_telephone is not None:
            self.company_telephone = company_telephone
        if company_vat_number is not None:
            self.company_vat_number = company_vat_number
        if employee_count is not None:
            self.employee_count = employee_count

    @property
    def successful(self):
        """Gets the successful of this LeadEnrichmentResponse.  # noqa: E501

        True if the operation was successful, false otherwise  # noqa: E501

        :return: The successful of this LeadEnrichmentResponse.  # noqa: E501
        :rtype: bool
        """
        return self._successful

    @successful.setter
    def successful(self, successful):
        """Sets the successful of this LeadEnrichmentResponse.

        True if the operation was successful, false otherwise  # noqa: E501

        :param successful: The successful of this LeadEnrichmentResponse.  # noqa: E501
        :type: bool
        """

        self._successful = successful

    @property
    def lead_type(self):
        """Gets the lead_type of this LeadEnrichmentResponse.  # noqa: E501

        The type of the lead; possible types are Junk (a single individual using a disposable/throwaway email address); Individual (a single individual, typically a consumer, not purchasing on behalf of a business); SmallBusiness (a small business, typically with fewer than 100 employees); MediumBusiness (a medium business, larger than 100 employees but fewer than 1000 employees); Enterprise (a large business with greater than 1000 employees); Business (a business customer of unknown size)  # noqa: E501

        :return: The lead_type of this LeadEnrichmentResponse.  # noqa: E501
        :rtype: str
        """
        return self._lead_type

    @lead_type.setter
    def lead_type(self, lead_type):
        """Sets the lead_type of this LeadEnrichmentResponse.

        The type of the lead; possible types are Junk (a single individual using a disposable/throwaway email address); Individual (a single individual, typically a consumer, not purchasing on behalf of a business); SmallBusiness (a small business, typically with fewer than 100 employees); MediumBusiness (a medium business, larger than 100 employees but fewer than 1000 employees); Enterprise (a large business with greater than 1000 employees); Business (a business customer of unknown size)  # noqa: E501

        :param lead_type: The lead_type of this LeadEnrichmentResponse.  # noqa: E501
        :type: str
        """

        self._lead_type = lead_type

    @property
    def contact_business_email(self):
        """Gets the contact_business_email of this LeadEnrichmentResponse.  # noqa: E501

        The person's business email address for the lead  # noqa: E501

        :return: The contact_business_email of this LeadEnrichmentResponse.  # noqa: E501
        :rtype: str
        """
        return self._contact_business_email

    @contact_business_email.setter
    def contact_business_email(self, contact_business_email):
        """Sets the contact_business_email of this LeadEnrichmentResponse.

        The person's business email address for the lead  # noqa: E501

        :param contact_business_email: The contact_business_email of this LeadEnrichmentResponse.  # noqa: E501
        :type: str
        """

        self._contact_business_email = contact_business_email

    @property
    def contact_first_name(self):
        """Gets the contact_first_name of this LeadEnrichmentResponse.  # noqa: E501

        The person's first name for the lead  # noqa: E501

        :return: The contact_first_name of this LeadEnrichmentResponse.  # noqa: E501
        :rtype: str
        """
        return self._contact_first_name

    @contact_first_name.setter
    def contact_first_name(self, contact_first_name):
        """Sets the contact_first_name of this LeadEnrichmentResponse.

        The person's first name for the lead  # noqa: E501

        :param contact_first_name: The contact_first_name of this LeadEnrichmentResponse.  # noqa: E501
        :type: str
        """

        self._contact_first_name = contact_first_name

    @property
    def contact_last_name(self):
        """Gets the contact_last_name of this LeadEnrichmentResponse.  # noqa: E501

        The person's last name for the lead  # noqa: E501

        :return: The contact_last_name of this LeadEnrichmentResponse.  # noqa: E501
        :rtype: str
        """
        return self._contact_last_name

    @contact_last_name.setter
    def contact_last_name(self, contact_last_name):
        """Sets the contact_last_name of this LeadEnrichmentResponse.

        The person's last name for the lead  # noqa: E501

        :param contact_last_name: The contact_last_name of this LeadEnrichmentResponse.  # noqa: E501
        :type: str
        """

        self._contact_last_name = contact_last_name

    @property
    def contact_gender(self):
        """Gets the contact_gender of this LeadEnrichmentResponse.  # noqa: E501

        Gender for contact name; possible values are Male, Female, and Neutral (can be applied to Male or Female).  Requires ContactFirstName.  # noqa: E501

        :return: The contact_gender of this LeadEnrichmentResponse.  # noqa: E501
        :rtype: str
        """
        return self._contact_gender

    @contact_gender.setter
    def contact_gender(self, contact_gender):
        """Sets the contact_gender of this LeadEnrichmentResponse.

        Gender for contact name; possible values are Male, Female, and Neutral (can be applied to Male or Female).  Requires ContactFirstName.  # noqa: E501

        :param contact_gender: The contact_gender of this LeadEnrichmentResponse.  # noqa: E501
        :type: str
        """

        self._contact_gender = contact_gender

    @property
    def company_name(self):
        """Gets the company_name of this LeadEnrichmentResponse.  # noqa: E501

        Name of the company for the lead  # noqa: E501

        :return: The company_name of this LeadEnrichmentResponse.  # noqa: E501
        :rtype: str
        """
        return self._company_name

    @company_name.setter
    def company_name(self, company_name):
        """Sets the company_name of this LeadEnrichmentResponse.

        Name of the company for the lead  # noqa: E501

        :param company_name: The company_name of this LeadEnrichmentResponse.  # noqa: E501
        :type: str
        """

        self._company_name = company_name

    @property
    def company_domain_name(self):
        """Gets the company_domain_name of this LeadEnrichmentResponse.  # noqa: E501

        Domain name / website for the lead  # noqa: E501

        :return: The company_domain_name of this LeadEnrichmentResponse.  # noqa: E501
        :rtype: str
        """
        return self._company_domain_name

    @company_domain_name.setter
    def company_domain_name(self, company_domain_name):
        """Sets the company_domain_name of this LeadEnrichmentResponse.

        Domain name / website for the lead  # noqa: E501

        :param company_domain_name: The company_domain_name of this LeadEnrichmentResponse.  # noqa: E501
        :type: str
        """

        self._company_domain_name = company_domain_name

    @property
    def company_house_number(self):
        """Gets the company_house_number of this LeadEnrichmentResponse.  # noqa: E501

        House number of the address of the company for the lead  # noqa: E501

        :return: The company_house_number of this LeadEnrichmentResponse.  # noqa: E501
        :rtype: str
        """
        return self._company_house_number

    @company_house_number.setter
    def company_house_number(self, company_house_number):
        """Sets the company_house_number of this LeadEnrichmentResponse.

        House number of the address of the company for the lead  # noqa: E501

        :param company_house_number: The company_house_number of this LeadEnrichmentResponse.  # noqa: E501
        :type: str
        """

        self._company_house_number = company_house_number

    @property
    def company_street(self):
        """Gets the company_street of this LeadEnrichmentResponse.  # noqa: E501

        Street name of the address of the company for the lead  # noqa: E501

        :return: The company_street of this LeadEnrichmentResponse.  # noqa: E501
        :rtype: str
        """
        return self._company_street

    @company_street.setter
    def company_street(self, company_street):
        """Sets the company_street of this LeadEnrichmentResponse.

        Street name of the address of the company for the lead  # noqa: E501

        :param company_street: The company_street of this LeadEnrichmentResponse.  # noqa: E501
        :type: str
        """

        self._company_street = company_street

    @property
    def company_city(self):
        """Gets the company_city of this LeadEnrichmentResponse.  # noqa: E501

        City of the address of the company for the lead  # noqa: E501

        :return: The company_city of this LeadEnrichmentResponse.  # noqa: E501
        :rtype: str
        """
        return self._company_city

    @company_city.setter
    def company_city(self, company_city):
        """Sets the company_city of this LeadEnrichmentResponse.

        City of the address of the company for the lead  # noqa: E501

        :param company_city: The company_city of this LeadEnrichmentResponse.  # noqa: E501
        :type: str
        """

        self._company_city = company_city

    @property
    def company_state_or_province(self):
        """Gets the company_state_or_province of this LeadEnrichmentResponse.  # noqa: E501

        State or Province of the address of the company for the lead  # noqa: E501

        :return: The company_state_or_province of this LeadEnrichmentResponse.  # noqa: E501
        :rtype: str
        """
        return self._company_state_or_province

    @company_state_or_province.setter
    def company_state_or_province(self, company_state_or_province):
        """Sets the company_state_or_province of this LeadEnrichmentResponse.

        State or Province of the address of the company for the lead  # noqa: E501

        :param company_state_or_province: The company_state_or_province of this LeadEnrichmentResponse.  # noqa: E501
        :type: str
        """

        self._company_state_or_province = company_state_or_province

    @property
    def company_postal_code(self):
        """Gets the company_postal_code of this LeadEnrichmentResponse.  # noqa: E501

        Postal Code of the address of the company for the lead  # noqa: E501

        :return: The company_postal_code of this LeadEnrichmentResponse.  # noqa: E501
        :rtype: str
        """
        return self._company_postal_code

    @company_postal_code.setter
    def company_postal_code(self, company_postal_code):
        """Sets the company_postal_code of this LeadEnrichmentResponse.

        Postal Code of the address of the company for the lead  # noqa: E501

        :param company_postal_code: The company_postal_code of this LeadEnrichmentResponse.  # noqa: E501
        :type: str
        """

        self._company_postal_code = company_postal_code

    @property
    def company_country(self):
        """Gets the company_country of this LeadEnrichmentResponse.  # noqa: E501

        Country Name of the address of the company for the lead  # noqa: E501

        :return: The company_country of this LeadEnrichmentResponse.  # noqa: E501
        :rtype: str
        """
        return self._company_country

    @company_country.setter
    def company_country(self, company_country):
        """Sets the company_country of this LeadEnrichmentResponse.

        Country Name of the address of the company for the lead  # noqa: E501

        :param company_country: The company_country of this LeadEnrichmentResponse.  # noqa: E501
        :type: str
        """

        self._company_country = company_country

    @property
    def company_country_code(self):
        """Gets the company_country_code of this LeadEnrichmentResponse.  # noqa: E501

        Country Code (2-letter ISO 3166-1) of the address of the company for the lead  # noqa: E501

        :return: The company_country_code of this LeadEnrichmentResponse.  # noqa: E501
        :rtype: str
        """
        return self._company_country_code

    @company_country_code.setter
    def company_country_code(self, company_country_code):
        """Sets the company_country_code of this LeadEnrichmentResponse.

        Country Code (2-letter ISO 3166-1) of the address of the company for the lead  # noqa: E501

        :param company_country_code: The company_country_code of this LeadEnrichmentResponse.  # noqa: E501
        :type: str
        """

        self._company_country_code = company_country_code

    @property
    def company_telephone(self):
        """Gets the company_telephone of this LeadEnrichmentResponse.  # noqa: E501

        Telephone of the company office for the lead  # noqa: E501

        :return: The company_telephone of this LeadEnrichmentResponse.  # noqa: E501
        :rtype: str
        """
        return self._company_telephone

    @company_telephone.setter
    def company_telephone(self, company_telephone):
        """Sets the company_telephone of this LeadEnrichmentResponse.

        Telephone of the company office for the lead  # noqa: E501

        :param company_telephone: The company_telephone of this LeadEnrichmentResponse.  # noqa: E501
        :type: str
        """

        self._company_telephone = company_telephone

    @property
    def company_vat_number(self):
        """Gets the company_vat_number of this LeadEnrichmentResponse.  # noqa: E501

        VAT number of the company for the lead  # noqa: E501

        :return: The company_vat_number of this LeadEnrichmentResponse.  # noqa: E501
        :rtype: str
        """
        return self._company_vat_number

    @company_vat_number.setter
    def company_vat_number(self, company_vat_number):
        """Sets the company_vat_number of this LeadEnrichmentResponse.

        VAT number of the company for the lead  # noqa: E501

        :param company_vat_number: The company_vat_number of this LeadEnrichmentResponse.  # noqa: E501
        :type: str
        """

        self._company_vat_number = company_vat_number

    @property
    def employee_count(self):
        """Gets the employee_count of this LeadEnrichmentResponse.  # noqa: E501

        Count of employees at the company (estimated), if available  # noqa: E501

        :return: The employee_count of this LeadEnrichmentResponse.  # noqa: E501
        :rtype: int
        """
        return self._employee_count

    @employee_count.setter
    def employee_count(self, employee_count):
        """Sets the employee_count of this LeadEnrichmentResponse.

        Count of employees at the company (estimated), if available  # noqa: E501

        :param employee_count: The employee_count of this LeadEnrichmentResponse.  # noqa: E501
        :type: int
        """

        self._employee_count = employee_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LeadEnrichmentResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LeadEnrichmentResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    validateapi

    The validation APIs help you validate data. Check if an E-mail address is real. Check if a domain is real. Check up on an IP address, and even where it is located. All this and much more is available in the validation API.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class IPIntelligenceResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'is_bot': 'bool',
        'is_tor_node': 'bool',
        'is_threat': 'bool',
        'is_eu': 'bool',
        'location': 'GeolocateResponse',
        'currency_code': 'str',
        'currency_name': 'str',
        'region_area': 'str',
        'subregion_area': 'str'
    }

    attribute_map = {
        'is_bot': 'IsBot',
        'is_tor_node': 'IsTorNode',
        'is_threat': 'IsThreat',
        'is_eu': 'IsEU',
        'location': 'Location',
        'currency_code': 'CurrencyCode',
        'currency_name': 'CurrencyName',
        'region_area': 'RegionArea',
        'subregion_area': 'SubregionArea'
    }

    def __init__(self, is_bot=None, is_tor_node=None, is_threat=None, is_eu=None, location=None, currency_code=None, currency_name=None, region_area=None, subregion_area=None):  # noqa: E501
        """IPIntelligenceResponse - a model defined in Swagger"""  # noqa: E501

        self._is_bot = None
        self._is_tor_node = None
        self._is_threat = None
        self._is_eu = None
        self._location = None
        self._currency_code = None
        self._currency_name = None
        self._region_area = None
        self._subregion_area = None
        self.discriminator = None

        if is_bot is not None:
            self.is_bot = is_bot
        if is_tor_node is not None:
            self.is_tor_node = is_tor_node
        if is_threat is not None:
            self.is_threat = is_threat
        if is_eu is not None:
            self.is_eu = is_eu
        if location is not None:
            self.location = location
        if currency_code is not None:
            self.currency_code = currency_code
        if currency_name is not None:
            self.currency_name = currency_name
        if region_area is not None:
            self.region_area = region_area
        if subregion_area is not None:
            self.subregion_area = subregion_area

    @property
    def is_bot(self):
        """Gets the is_bot of this IPIntelligenceResponse.  # noqa: E501

        True if the IP address is a known bot, otherwise false  # noqa: E501

        :return: The is_bot of this IPIntelligenceResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_bot

    @is_bot.setter
    def is_bot(self, is_bot):
        """Sets the is_bot of this IPIntelligenceResponse.

        True if the IP address is a known bot, otherwise false  # noqa: E501

        :param is_bot: The is_bot of this IPIntelligenceResponse.  # noqa: E501
        :type: bool
        """

        self._is_bot = is_bot

    @property
    def is_tor_node(self):
        """Gets the is_tor_node of this IPIntelligenceResponse.  # noqa: E501

        True if the IP address is a known Tor exit node, otherwise false  # noqa: E501

        :return: The is_tor_node of this IPIntelligenceResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_tor_node

    @is_tor_node.setter
    def is_tor_node(self, is_tor_node):
        """Sets the is_tor_node of this IPIntelligenceResponse.

        True if the IP address is a known Tor exit node, otherwise false  # noqa: E501

        :param is_tor_node: The is_tor_node of this IPIntelligenceResponse.  # noqa: E501
        :type: bool
        """

        self._is_tor_node = is_tor_node

    @property
    def is_threat(self):
        """Gets the is_threat of this IPIntelligenceResponse.  # noqa: E501

        True if the IP address is a known threat IP, otherwise false  # noqa: E501

        :return: The is_threat of this IPIntelligenceResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_threat

    @is_threat.setter
    def is_threat(self, is_threat):
        """Sets the is_threat of this IPIntelligenceResponse.

        True if the IP address is a known threat IP, otherwise false  # noqa: E501

        :param is_threat: The is_threat of this IPIntelligenceResponse.  # noqa: E501
        :type: bool
        """

        self._is_threat = is_threat

    @property
    def is_eu(self):
        """Gets the is_eu of this IPIntelligenceResponse.  # noqa: E501

        True if the IP address is in the European Union, otherwise false  # noqa: E501

        :return: The is_eu of this IPIntelligenceResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_eu

    @is_eu.setter
    def is_eu(self, is_eu):
        """Sets the is_eu of this IPIntelligenceResponse.

        True if the IP address is in the European Union, otherwise false  # noqa: E501

        :param is_eu: The is_eu of this IPIntelligenceResponse.  # noqa: E501
        :type: bool
        """

        self._is_eu = is_eu

    @property
    def location(self):
        """Gets the location of this IPIntelligenceResponse.  # noqa: E501

        Returns the location of the IP address  # noqa: E501

        :return: The location of this IPIntelligenceResponse.  # noqa: E501
        :rtype: GeolocateResponse
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this IPIntelligenceResponse.

        Returns the location of the IP address  # noqa: E501

        :param location: The location of this IPIntelligenceResponse.  # noqa: E501
        :type: GeolocateResponse
        """

        self._location = location

    @property
    def currency_code(self):
        """Gets the currency_code of this IPIntelligenceResponse.  # noqa: E501

        ISO 4217 currency code for the IP address location  # noqa: E501

        :return: The currency_code of this IPIntelligenceResponse.  # noqa: E501
        :rtype: str
        """
        return self._currency_code

    @currency_code.setter
    def currency_code(self, currency_code):
        """Sets the currency_code of this IPIntelligenceResponse.

        ISO 4217 currency code for the IP address location  # noqa: E501

        :param currency_code: The currency_code of this IPIntelligenceResponse.  # noqa: E501
        :type: str
        """

        self._currency_code = currency_code

    @property
    def currency_name(self):
        """Gets the currency_name of this IPIntelligenceResponse.  # noqa: E501

        Name of the currency in English  # noqa: E501

        :return: The currency_name of this IPIntelligenceResponse.  # noqa: E501
        :rtype: str
        """
        return self._currency_name

    @currency_name.setter
    def currency_name(self, currency_name):
        """Sets the currency_name of this IPIntelligenceResponse.

        Name of the currency in English  # noqa: E501

        :param currency_name: The currency_name of this IPIntelligenceResponse.  # noqa: E501
        :type: str
        """

        self._currency_name = currency_name

    @property
    def region_area(self):
        """Gets the region_area of this IPIntelligenceResponse.  # noqa: E501

        Region (continent) in which the country is located; possible values are None, Europe, Americas, Asia, Africa, Oceania  # noqa: E501

        :return: The region_area of this IPIntelligenceResponse.  # noqa: E501
        :rtype: str
        """
        return self._region_area

    @region_area.setter
    def region_area(self, region_area):
        """Sets the region_area of this IPIntelligenceResponse.

        Region (continent) in which the country is located; possible values are None, Europe, Americas, Asia, Africa, Oceania  # noqa: E501

        :param region_area: The region_area of this IPIntelligenceResponse.  # noqa: E501
        :type: str
        """

        self._region_area = region_area

    @property
    def subregion_area(self):
        """Gets the subregion_area of this IPIntelligenceResponse.  # noqa: E501

        Subregion in which the country is located; possible values are None, NorthernEurope, WesternEurope, SouthernEurope, EasternEurope, CentralAmerica, NorthernAmerica, SouthAmerica, EasternAfrica, MiddleAfrica, NorthernAfrica , SouthernAfrica , WesternAfrica , CentralAsia , EasternAsia , SouthernAsia , SouthEasternAsia , WesternAsia , Southern , Middle , AustraliaandNewZealand , Melanesia , Polynesia , Micronesia , Caribbean,  # noqa: E501

        :return: The subregion_area of this IPIntelligenceResponse.  # noqa: E501
        :rtype: str
        """
        return self._subregion_area

    @subregion_area.setter
    def subregion_area(self, subregion_area):
        """Sets the subregion_area of this IPIntelligenceResponse.

        Subregion in which the country is located; possible values are None, NorthernEurope, WesternEurope, SouthernEurope, EasternEurope, CentralAmerica, NorthernAmerica, SouthAmerica, EasternAfrica, MiddleAfrica, NorthernAfrica , SouthernAfrica , WesternAfrica , CentralAsia , EasternAsia , SouthernAsia , SouthEasternAsia , WesternAsia , Southern , Middle , AustraliaandNewZealand , Melanesia , Polynesia , Micronesia , Caribbean,  # noqa: E501

        :param subregion_area: The subregion_area of this IPIntelligenceResponse.  # noqa: E501
        :type: str
        """

        self._subregion_area = subregion_area

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(IPIntelligenceResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IPIntelligenceResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    validateapi

    The validation APIs help you validate data. Check if an E-mail address is real. Check if a domain is real. Check up on an IP address, and even where it is located. All this and much more is available in the validation API.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ValidateIdentifierRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'input': 'str',
        'allow_whitespace': 'bool',
        'allow_hyphens': 'bool',
        'allow_underscore': 'bool',
        'allow_numbers': 'bool',
        'allow_periods': 'bool',
        'max_length': 'int',
        'min_length': 'int'
    }

    attribute_map = {
        'input': 'Input',
        'allow_whitespace': 'AllowWhitespace',
        'allow_hyphens': 'AllowHyphens',
        'allow_underscore': 'AllowUnderscore',
        'allow_numbers': 'AllowNumbers',
        'allow_periods': 'AllowPeriods',
        'max_length': 'MaxLength',
        'min_length': 'MinLength'
    }

    def __init__(self, input=None, allow_whitespace=None, allow_hyphens=None, allow_underscore=None, allow_numbers=None, allow_periods=None, max_length=None, min_length=None):  # noqa: E501
        """ValidateIdentifierRequest - a model defined in Swagger"""  # noqa: E501

        self._input = None
        self._allow_whitespace = None
        self._allow_hyphens = None
        self._allow_underscore = None
        self._allow_numbers = None
        self._allow_periods = None
        self._max_length = None
        self._min_length = None
        self.discriminator = None

        if input is not None:
            self.input = input
        if allow_whitespace is not None:
            self.allow_whitespace = allow_whitespace
        if allow_hyphens is not None:
            self.allow_hyphens = allow_hyphens
        if allow_underscore is not None:
            self.allow_underscore = allow_underscore
        if allow_numbers is not None:
            self.allow_numbers = allow_numbers
        if allow_periods is not None:
            self.allow_periods = allow_periods
        if max_length is not None:
            self.max_length = max_length
        if min_length is not None:
            self.min_length = min_length

    @property
    def input(self):
        """Gets the input of this ValidateIdentifierRequest.  # noqa: E501

        Text string identifier input  # noqa: E501

        :return: The input of this ValidateIdentifierRequest.  # noqa: E501
        :rtype: str
        """
        return self._input

    @input.setter
    def input(self, input):
        """Sets the input of this ValidateIdentifierRequest.

        Text string identifier input  # noqa: E501

        :param input: The input of this ValidateIdentifierRequest.  # noqa: E501
        :type: str
        """

        self._input = input

    @property
    def allow_whitespace(self):
        """Gets the allow_whitespace of this ValidateIdentifierRequest.  # noqa: E501

        True if whitespace is allowed in the identifier, false otherwise  # noqa: E501

        :return: The allow_whitespace of this ValidateIdentifierRequest.  # noqa: E501
        :rtype: bool
        """
        return self._allow_whitespace

    @allow_whitespace.setter
    def allow_whitespace(self, allow_whitespace):
        """Sets the allow_whitespace of this ValidateIdentifierRequest.

        True if whitespace is allowed in the identifier, false otherwise  # noqa: E501

        :param allow_whitespace: The allow_whitespace of this ValidateIdentifierRequest.  # noqa: E501
        :type: bool
        """

        self._allow_whitespace = allow_whitespace

    @property
    def allow_hyphens(self):
        """Gets the allow_hyphens of this ValidateIdentifierRequest.  # noqa: E501

        True if hyphens are allowd in the identifier, false otherwise  # noqa: E501

        :return: The allow_hyphens of this ValidateIdentifierRequest.  # noqa: E501
        :rtype: bool
        """
        return self._allow_hyphens

    @allow_hyphens.setter
    def allow_hyphens(self, allow_hyphens):
        """Sets the allow_hyphens of this ValidateIdentifierRequest.

        True if hyphens are allowd in the identifier, false otherwise  # noqa: E501

        :param allow_hyphens: The allow_hyphens of this ValidateIdentifierRequest.  # noqa: E501
        :type: bool
        """

        self._allow_hyphens = allow_hyphens

    @property
    def allow_underscore(self):
        """Gets the allow_underscore of this ValidateIdentifierRequest.  # noqa: E501

        True if underscores are allowed in the identifier, false otherwise  # noqa: E501

        :return: The allow_underscore of this ValidateIdentifierRequest.  # noqa: E501
        :rtype: bool
        """
        return self._allow_underscore

    @allow_underscore.setter
    def allow_underscore(self, allow_underscore):
        """Sets the allow_underscore of this ValidateIdentifierRequest.

        True if underscores are allowed in the identifier, false otherwise  # noqa: E501

        :param allow_underscore: The allow_underscore of this ValidateIdentifierRequest.  # noqa: E501
        :type: bool
        """

        self._allow_underscore = allow_underscore

    @property
    def allow_numbers(self):
        """Gets the allow_numbers of this ValidateIdentifierRequest.  # noqa: E501

        True if numbers are allowed in the identifier, false otherwise  # noqa: E501

        :return: The allow_numbers of this ValidateIdentifierRequest.  # noqa: E501
        :rtype: bool
        """
        return self._allow_numbers

    @allow_numbers.setter
    def allow_numbers(self, allow_numbers):
        """Sets the allow_numbers of this ValidateIdentifierRequest.

        True if numbers are allowed in the identifier, false otherwise  # noqa: E501

        :param allow_numbers: The allow_numbers of this ValidateIdentifierRequest.  # noqa: E501
        :type: bool
        """

        self._allow_numbers = allow_numbers

    @property
    def allow_periods(self):
        """Gets the allow_periods of this ValidateIdentifierRequest.  # noqa: E501

        True if periods are allowed in the identifier, false otherwise  # noqa: E501

        :return: The allow_periods of this ValidateIdentifierRequest.  # noqa: E501
        :rtype: bool
        """
        return self._allow_periods

    @allow_periods.setter
    def allow_periods(self, allow_periods):
        """Sets the allow_periods of this ValidateIdentifierRequest.

        True if periods are allowed in the identifier, false otherwise  # noqa: E501

        :param allow_periods: The allow_periods of this ValidateIdentifierRequest.  # noqa: E501
        :type: bool
        """

        self._allow_periods = allow_periods

    @property
    def max_length(self):
        """Gets the max_length of this ValidateIdentifierRequest.  # noqa: E501

        Optional; maximum length, if any, of the identifier  # noqa: E501

        :return: The max_length of this ValidateIdentifierRequest.  # noqa: E501
        :rtype: int
        """
        return self._max_length

    @max_length.setter
    def max_length(self, max_length):
        """Sets the max_length of this ValidateIdentifierRequest.

        Optional; maximum length, if any, of the identifier  # noqa: E501

        :param max_length: The max_length of this ValidateIdentifierRequest.  # noqa: E501
        :type: int
        """

        self._max_length = max_length

    @property
    def min_length(self):
        """Gets the min_length of this ValidateIdentifierRequest.  # noqa: E501

        Optional; minimum length, if any, of the identifier  # noqa: E501

        :return: The min_length of this ValidateIdentifierRequest.  # noqa: E501
        :rtype: int
        """
        return self._min_length

    @min_length.setter
    def min_length(self, min_length):
        """Sets the min_length of this ValidateIdentifierRequest.

        Optional; minimum length, if any, of the identifier  # noqa: E501

        :param min_length: The min_length of this ValidateIdentifierRequest.  # noqa: E501
        :type: int
        """

        self._min_length = min_length

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ValidateIdentifierRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ValidateIdentifierRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    validateapi

    The validation APIs help you validate data. Check if an E-mail address is real. Check if a domain is real. Check up on an IP address, and even where it is located. All this and much more is available in the validation API.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class VatLookupResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'country_code': 'str',
        'vat_number': 'str',
        'is_valid': 'bool',
        'business_name': 'str',
        'business_address': 'str',
        'business_building': 'str',
        'business_street_number': 'str',
        'business_street': 'str',
        'business_city': 'str',
        'business_state_or_province': 'str',
        'business_postal_code': 'str',
        'business_country': 'str'
    }

    attribute_map = {
        'country_code': 'CountryCode',
        'vat_number': 'VatNumber',
        'is_valid': 'IsValid',
        'business_name': 'BusinessName',
        'business_address': 'BusinessAddress',
        'business_building': 'BusinessBuilding',
        'business_street_number': 'BusinessStreetNumber',
        'business_street': 'BusinessStreet',
        'business_city': 'BusinessCity',
        'business_state_or_province': 'BusinessStateOrProvince',
        'business_postal_code': 'BusinessPostalCode',
        'business_country': 'BusinessCountry'
    }

    def __init__(self, country_code=None, vat_number=None, is_valid=None, business_name=None, business_address=None, business_building=None, business_street_number=None, business_street=None, business_city=None, business_state_or_province=None, business_postal_code=None, business_country=None):  # noqa: E501
        """VatLookupResponse - a model defined in Swagger"""  # noqa: E501

        self._country_code = None
        self._vat_number = None
        self._is_valid = None
        self._business_name = None
        self._business_address = None
        self._business_building = None
        self._business_street_number = None
        self._business_street = None
        self._business_city = None
        self._business_state_or_province = None
        self._business_postal_code = None
        self._business_country = None
        self.discriminator = None

        if country_code is not None:
            self.country_code = country_code
        if vat_number is not None:
            self.vat_number = vat_number
        if is_valid is not None:
            self.is_valid = is_valid
        if business_name is not None:
            self.business_name = business_name
        if business_address is not None:
            self.business_address = business_address
        if business_building is not None:
            self.business_building = business_building
        if business_street_number is not None:
            self.business_street_number = business_street_number
        if business_street is not None:
            self.business_street = business_street
        if business_city is not None:
            self.business_city = business_city
        if business_state_or_province is not None:
            self.business_state_or_province = business_state_or_province
        if business_postal_code is not None:
            self.business_postal_code = business_postal_code
        if business_country is not None:
            self.business_country = business_country

    @property
    def country_code(self):
        """Gets the country_code of this VatLookupResponse.  # noqa: E501

        Two-letter country code  # noqa: E501

        :return: The country_code of this VatLookupResponse.  # noqa: E501
        :rtype: str
        """
        return self._country_code

    @country_code.setter
    def country_code(self, country_code):
        """Sets the country_code of this VatLookupResponse.

        Two-letter country code  # noqa: E501

        :param country_code: The country_code of this VatLookupResponse.  # noqa: E501
        :type: str
        """

        self._country_code = country_code

    @property
    def vat_number(self):
        """Gets the vat_number of this VatLookupResponse.  # noqa: E501

        VAT number  # noqa: E501

        :return: The vat_number of this VatLookupResponse.  # noqa: E501
        :rtype: str
        """
        return self._vat_number

    @vat_number.setter
    def vat_number(self, vat_number):
        """Sets the vat_number of this VatLookupResponse.

        VAT number  # noqa: E501

        :param vat_number: The vat_number of this VatLookupResponse.  # noqa: E501
        :type: str
        """

        self._vat_number = vat_number

    @property
    def is_valid(self):
        """Gets the is_valid of this VatLookupResponse.  # noqa: E501

        True if the VAT code is valid, false otherwise  # noqa: E501

        :return: The is_valid of this VatLookupResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_valid

    @is_valid.setter
    def is_valid(self, is_valid):
        """Sets the is_valid of this VatLookupResponse.

        True if the VAT code is valid, false otherwise  # noqa: E501

        :param is_valid: The is_valid of this VatLookupResponse.  # noqa: E501
        :type: bool
        """

        self._is_valid = is_valid

    @property
    def business_name(self):
        """Gets the business_name of this VatLookupResponse.  # noqa: E501

        Name of the business  # noqa: E501

        :return: The business_name of this VatLookupResponse.  # noqa: E501
        :rtype: str
        """
        return self._business_name

    @business_name.setter
    def business_name(self, business_name):
        """Sets the business_name of this VatLookupResponse.

        Name of the business  # noqa: E501

        :param business_name: The business_name of this VatLookupResponse.  # noqa: E501
        :type: str
        """

        self._business_name = business_name

    @property
    def business_address(self):
        """Gets the business_address of this VatLookupResponse.  # noqa: E501

        Business address as a single string  # noqa: E501

        :return: The business_address of this VatLookupResponse.  # noqa: E501
        :rtype: str
        """
        return self._business_address

    @business_address.setter
    def business_address(self, business_address):
        """Sets the business_address of this VatLookupResponse.

        Business address as a single string  # noqa: E501

        :param business_address: The business_address of this VatLookupResponse.  # noqa: E501
        :type: str
        """

        self._business_address = business_address

    @property
    def business_building(self):
        """Gets the business_building of this VatLookupResponse.  # noqa: E501

        For the business address, the name of the building, house or structure if applicable, such as \"Cloudmersive Building 2\".  This will often by null.  # noqa: E501

        :return: The business_building of this VatLookupResponse.  # noqa: E501
        :rtype: str
        """
        return self._business_building

    @business_building.setter
    def business_building(self, business_building):
        """Sets the business_building of this VatLookupResponse.

        For the business address, the name of the building, house or structure if applicable, such as \"Cloudmersive Building 2\".  This will often by null.  # noqa: E501

        :param business_building: The business_building of this VatLookupResponse.  # noqa: E501
        :type: str
        """

        self._business_building = business_building

    @property
    def business_street_number(self):
        """Gets the business_street_number of this VatLookupResponse.  # noqa: E501

        For the business address, the street number or house number of the address.  For example, in the address \"1600 Pennsylvania Avenue NW\" the street number would be \"1600\".  This value will typically be populated for most addresses.  # noqa: E501

        :return: The business_street_number of this VatLookupResponse.  # noqa: E501
        :rtype: str
        """
        return self._business_street_number

    @business_street_number.setter
    def business_street_number(self, business_street_number):
        """Sets the business_street_number of this VatLookupResponse.

        For the business address, the street number or house number of the address.  For example, in the address \"1600 Pennsylvania Avenue NW\" the street number would be \"1600\".  This value will typically be populated for most addresses.  # noqa: E501

        :param business_street_number: The business_street_number of this VatLookupResponse.  # noqa: E501
        :type: str
        """

        self._business_street_number = business_street_number

    @property
    def business_street(self):
        """Gets the business_street of this VatLookupResponse.  # noqa: E501

        For the business address, the name of the street or road of the address.  For example, in the address \"1600 Pennsylvania Avenue NW\" the street number would be \"Pennsylvania Avenue NW\".  # noqa: E501

        :return: The business_street of this VatLookupResponse.  # noqa: E501
        :rtype: str
        """
        return self._business_street

    @business_street.setter
    def business_street(self, business_street):
        """Sets the business_street of this VatLookupResponse.

        For the business address, the name of the street or road of the address.  For example, in the address \"1600 Pennsylvania Avenue NW\" the street number would be \"Pennsylvania Avenue NW\".  # noqa: E501

        :param business_street: The business_street of this VatLookupResponse.  # noqa: E501
        :type: str
        """

        self._business_street = business_street

    @property
    def business_city(self):
        """Gets the business_city of this VatLookupResponse.  # noqa: E501

        For the business address, the city of the address.  # noqa: E501

        :return: The business_city of this VatLookupResponse.  # noqa: E501
        :rtype: str
        """
        return self._business_city

    @business_city.setter
    def business_city(self, business_city):
        """Sets the business_city of this VatLookupResponse.

        For the business address, the city of the address.  # noqa: E501

        :param business_city: The business_city of this VatLookupResponse.  # noqa: E501
        :type: str
        """

        self._business_city = business_city

    @property
    def business_state_or_province(self):
        """Gets the business_state_or_province of this VatLookupResponse.  # noqa: E501

        For the business address, the state or province of the address.  # noqa: E501

        :return: The business_state_or_province of this VatLookupResponse.  # noqa: E501
        :rtype: str
        """
        return self._business_state_or_province

    @business_state_or_province.setter
    def business_state_or_province(self, business_state_or_province):
        """Sets the business_state_or_province of this VatLookupResponse.

        For the business address, the state or province of the address.  # noqa: E501

        :param business_state_or_province: The business_state_or_province of this VatLookupResponse.  # noqa: E501
        :type: str
        """

        self._business_state_or_province = business_state_or_province

    @property
    def business_postal_code(self):
        """Gets the business_postal_code of this VatLookupResponse.  # noqa: E501

        For the business address, the postal code or zip code of the address.  # noqa: E501

        :return: The business_postal_code of this VatLookupResponse.  # noqa: E501
        :rtype: str
        """
        return self._business_postal_code

    @business_postal_code.setter
    def business_postal_code(self, business_postal_code):
        """Sets the business_postal_code of this VatLookupResponse.

        For the business address, the postal code or zip code of the address.  # noqa: E501

        :param business_postal_code: The business_postal_code of this VatLookupResponse.  # noqa: E501
        :type: str
        """

        self._business_postal_code = business_postal_code

    @property
    def business_country(self):
        """Gets the business_country of this VatLookupResponse.  # noqa: E501

        For the business address, country of the address, if present in the address.  If not included in the address it will be null.  # noqa: E501

        :return: The business_country of this VatLookupResponse.  # noqa: E501
        :rtype: str
        """
        return self._business_country

    @business_country.setter
    def business_country(self, business_country):
        """Sets the business_country of this VatLookupResponse.

        For the business address, country of the address, if present in the address.  If not included in the address it will be null.  # noqa: E501

        :param business_country: The business_country of this VatLookupResponse.  # noqa: E501
        :type: str
        """

        self._business_country = business_country

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(VatLookupResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VatLookupResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    validateapi

    The validation APIs help you validate data. Check if an E-mail address is real. Check if a domain is real. Check up on an IP address, and even where it is located. All this and much more is available in the validation API.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from cloudmersive_validate_api_client.api_client import ApiClient


class NameApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def name_get_gender(self, input, **kwargs):  # noqa: E501
        """Get the gender of a first name  # noqa: E501

        Determines the gender of a first name (given name)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.name_get_gender(input, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param GetGenderRequest input: Gender request information (required)
        :return: GetGenderResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.name_get_gender_with_http_info(input, **kwargs)  # noqa: E501
        else:
            (data) = self.name_get_gender_with_http_info(input, **kwargs)  # noqa: E501
            return data

    def name_get_gender_with_http_info(self, input, **kwargs):  # noqa: E501
        """Get the gender of a first name  # noqa: E501

        Determines the gender of a first name (given name)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.name_get_gender_with_http_info(input, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param GetGenderRequest input: Gender request information (required)
        :return: GetGenderResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method name_get_gender" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input' is set
        if ('input' not in params or
                params['input'] is None):
            raise ValueError("Missing the required parameter `input` when calling `name_get_gender`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'input' in params:
            body_params = params['input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/validate/name/get-gender', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetGenderResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def name_identifier(self, input, **kwargs):  # noqa: E501
        """Validate a code identifier  # noqa: E501

        Determines if the input name is a valid technical / code identifier.  Configure input rules such as whether whitespace, hyphens, underscores, etc. are allowed.  For example, a valid identifier might be \"helloWorld\" but not \"hello*World\".  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.name_identifier(input, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ValidateIdentifierRequest input: Identifier validation request information (required)
        :return: ValidateIdentifierResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.name_identifier_with_http_info(input, **kwargs)  # noqa: E501
        else:
            (data) = self.name_identifier_with_http_info(input, **kwargs)  # noqa: E501
            return data

    def name_identifier_with_http_info(self, input, **kwargs):  # noqa: E501
        """Validate a code identifier  # noqa: E501

        Determines if the input name is a valid technical / code identifier.  Configure input rules such as whether whitespace, hyphens, underscores, etc. are allowed.  For example, a valid identifier might be \"helloWorld\" but not \"hello*World\".  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.name_identifier_with_http_info(input, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ValidateIdentifierRequest input: Identifier validation request information (required)
        :return: ValidateIdentifierResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method name_identifier" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input' is set
        if ('input' not in params or
                params['input'] is None):
            raise ValueError("Missing the required parameter `input` when calling `name_identifier`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'input' in params:
            body_params = params['input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/validate/name/identifier', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ValidateIdentifierResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def name_validate_first_name(self, input, **kwargs):  # noqa: E501
        """Validate a first name  # noqa: E501

        Determines if a string is a valid first name (given name)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.name_validate_first_name(input, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param FirstNameValidationRequest input: Validation request information (required)
        :return: FirstNameValidationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.name_validate_first_name_with_http_info(input, **kwargs)  # noqa: E501
        else:
            (data) = self.name_validate_first_name_with_http_info(input, **kwargs)  # noqa: E501
            return data

    def name_validate_first_name_with_http_info(self, input, **kwargs):  # noqa: E501
        """Validate a first name  # noqa: E501

        Determines if a string is a valid first name (given name)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.name_validate_first_name_with_http_info(input, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param FirstNameValidationRequest input: Validation request information (required)
        :return: FirstNameValidationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method name_validate_first_name" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input' is set
        if ('input' not in params or
                params['input'] is None):
            raise ValueError("Missing the required parameter `input` when calling `name_validate_first_name`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'input' in params:
            body_params = params['input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/validate/name/first', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='FirstNameValidationResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def name_validate_full_name(self, input, **kwargs):  # noqa: E501
        """Parse and validate a full name  # noqa: E501

        Parses a full name string (e.g. \"Mr. Jon van der Waal Jr.\") into its component parts (and returns these component parts), and then validates whether it is a valid name string or not  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.name_validate_full_name(input, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param FullNameValidationRequest input: Validation request information (required)
        :return: FullNameValidationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.name_validate_full_name_with_http_info(input, **kwargs)  # noqa: E501
        else:
            (data) = self.name_validate_full_name_with_http_info(input, **kwargs)  # noqa: E501
            return data

    def name_validate_full_name_with_http_info(self, input, **kwargs):  # noqa: E501
        """Parse and validate a full name  # noqa: E501

        Parses a full name string (e.g. \"Mr. Jon van der Waal Jr.\") into its component parts (and returns these component parts), and then validates whether it is a valid name string or not  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.name_validate_full_name_with_http_info(input, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param FullNameValidationRequest input: Validation request information (required)
        :return: FullNameValidationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method name_validate_full_name" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input' is set
        if ('input' not in params or
                params['input'] is None):
            raise ValueError("Missing the required parameter `input` when calling `name_validate_full_name`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'input' in params:
            body_params = params['input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/validate/name/full-name', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='FullNameValidationResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def name_validate_last_name(self, input, **kwargs):  # noqa: E501
        """Validate a last name  # noqa: E501

        Determines if a string is a valid last name (surname)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.name_validate_last_name(input, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param LastNameValidationRequest input: Validation request information (required)
        :return: LastNameValidationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.name_validate_last_name_with_http_info(input, **kwargs)  # noqa: E501
        else:
            (data) = self.name_validate_last_name_with_http_info(input, **kwargs)  # noqa: E501
            return data

    def name_validate_last_name_with_http_info(self, input, **kwargs):  # noqa: E501
        """Validate a last name  # noqa: E501

        Determines if a string is a valid last name (surname)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.name_validate_last_name_with_http_info(input, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param LastNameValidationRequest input: Validation request information (required)
        :return: LastNameValidationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method name_validate_last_name" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input' is set
        if ('input' not in params or
                params['input'] is None):
            raise ValueError("Missing the required parameter `input` when calling `name_validate_last_name`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'input' in params:
            body_params = params['input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/validate/name/last', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='LastNameValidationResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    validateapi

    The validation APIs help you validate data. Check if an E-mail address is real. Check if a domain is real. Check up on an IP address, and even where it is located. All this and much more is available in the validation API.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class DateTimeNowResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'successful': 'bool',
        'now': 'datetime',
        'now_gmt': 'datetime'
    }

    attribute_map = {
        'successful': 'Successful',
        'now': 'Now',
        'now_gmt': 'NowGmt'
    }

    def __init__(self, successful=None, now=None, now_gmt=None):  # noqa: E501
        """DateTimeNowResult - a model defined in Swagger"""  # noqa: E501

        self._successful = None
        self._now = None
        self._now_gmt = None
        self.discriminator = None

        if successful is not None:
            self.successful = successful
        if now is not None:
            self.now = now
        if now_gmt is not None:
            self.now_gmt = now_gmt

    @property
    def successful(self):
        """Gets the successful of this DateTimeNowResult.  # noqa: E501

        True if successful, false otherwise  # noqa: E501

        :return: The successful of this DateTimeNowResult.  # noqa: E501
        :rtype: bool
        """
        return self._successful

    @successful.setter
    def successful(self, successful):
        """Sets the successful of this DateTimeNowResult.

        True if successful, false otherwise  # noqa: E501

        :param successful: The successful of this DateTimeNowResult.  # noqa: E501
        :type: bool
        """

        self._successful = successful

    @property
    def now(self):
        """Gets the now of this DateTimeNowResult.  # noqa: E501

        Current date, time, and time zone in standard JSON date format  # noqa: E501

        :return: The now of this DateTimeNowResult.  # noqa: E501
        :rtype: datetime
        """
        return self._now

    @now.setter
    def now(self, now):
        """Sets the now of this DateTimeNowResult.

        Current date, time, and time zone in standard JSON date format  # noqa: E501

        :param now: The now of this DateTimeNowResult.  # noqa: E501
        :type: datetime
        """

        self._now = now

    @property
    def now_gmt(self):
        """Gets the now_gmt of this DateTimeNowResult.  # noqa: E501

        Current GMT-time-zone date, time, and time zone in standard JSON date format  # noqa: E501

        :return: The now_gmt of this DateTimeNowResult.  # noqa: E501
        :rtype: datetime
        """
        return self._now_gmt

    @now_gmt.setter
    def now_gmt(self, now_gmt):
        """Sets the now_gmt of this DateTimeNowResult.

        Current GMT-time-zone date, time, and time zone in standard JSON date format  # noqa: E501

        :param now_gmt: The now_gmt of this DateTimeNowResult.  # noqa: E501
        :type: datetime
        """

        self._now_gmt = now_gmt

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DateTimeNowResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DateTimeNowResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    validateapi

    The validation APIs help you validate data. Check if an E-mail address is real. Check if a domain is real. Check up on an IP address, and even where it is located. All this and much more is available in the validation API.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class GetGenderRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'first_name': 'str',
        'country_code': 'str'
    }

    attribute_map = {
        'first_name': 'FirstName',
        'country_code': 'CountryCode'
    }

    def __init__(self, first_name=None, country_code=None):  # noqa: E501
        """GetGenderRequest - a model defined in Swagger"""  # noqa: E501

        self._first_name = None
        self._country_code = None
        self.discriminator = None

        if first_name is not None:
            self.first_name = first_name
        if country_code is not None:
            self.country_code = country_code

    @property
    def first_name(self):
        """Gets the first_name of this GetGenderRequest.  # noqa: E501

        Input first name (given name) to get the gender of  # noqa: E501

        :return: The first_name of this GetGenderRequest.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this GetGenderRequest.

        Input first name (given name) to get the gender of  # noqa: E501

        :param first_name: The first_name of this GetGenderRequest.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def country_code(self):
        """Gets the country_code of this GetGenderRequest.  # noqa: E501

        Optional; the country for this name, possible values are \"US\", \"LY\", \"NI\", \"TT\", \"MK\", \"KZ\", \"BO\", \"UG\", \"TZ\", \"CL\", \"SI\", \"MA\", \"RW\", \"VN\", \"AW\", \"CY\", \"BH\", \"SG\", \"ZA\", \"MU\", \"BR\", \"TN\", \"KH\", \"US\", \"TH\", \"TW\", \"UY\", \"DO\", \"CO\", \"UA\", \"QA\", \"BY\", \"SN\", \"SD\", \"FJ\", \"LB\", \"BE\", \"ML\", \"LV\", \"FR\", \"TM\", \"NG\", \"EC\", \"NO\", \"SL\", \"CR\", \"PA\", \"GE\", \"CH\", \"KR\", \"RS\", \"ZM\", \"FI\", \"BF\", \"MC\", \"AU\", \"GA\", \"LS\", \"RU\", \"IN\", \"SE\", \"LK\", \"BZ\", \"MX\", \"GH\", \"AF\", \"TJ\", \"BN\", \"DZ\", \"CM\", \"GR\", \"MD\", \"HN\", \"AT\", \"NZ\", \"SV\", \"GW\", \"NA\", \"AR\", \"MZ\", \"PK\", \"MN\", \"IQ\", \"BW\", \"VE\", \"PT\", \"BS\", \"AL\", \"TG\", \"ID\", \"ET\", \"CF\", \"JP\", \"BB\", \"PH\", \"CU\", \"BD\", \"AO\", \"SM\", \"LC\", \"ME\", \"RO\",  DANIL\"O\"\", \"ES\", \"EE\", \"IL\", \"ZW\", \"SY\", \"MW\", \"LU\", \"IR\", \"SC\", \"NL\", \"JO\", \"AM\", \"DE\", \"GL\", \"OM\", \"DK\", \"HR\", \"LI\", \"TD\", \"KM\", \"BA\", \"GM\", \"GD\", \"CA\", \"CZ\", \"MR\", \"ST\", \"IS\", \"LR\", \"IE\", \"VC\", \"AE\", \"KG\", \"DJ\", \"TR\", \"KE\", \"NE\", \"UZ\", \"CN\", \"GQ\", \"SK\", \"BJ\", \"MG\", \"BT\", \"EG\", \"PL\", \"IT\", \"SA\", \"MY\", \"CI\", \"AG\", \"AD\", \"KS\", \"HU\", \"CG\", \"KP\", \"DM\", \"GN\", \"GT\", \"NP\", \"JM\", \"LA\", \"GB\", \"BG\", \"HT\", \"PE\", \"AZ\", \"LT\", \"SZ\", \"PY\", \"MT\", \"VA\"  # noqa: E501

        :return: The country_code of this GetGenderRequest.  # noqa: E501
        :rtype: str
        """
        return self._country_code

    @country_code.setter
    def country_code(self, country_code):
        """Sets the country_code of this GetGenderRequest.

        Optional; the country for this name, possible values are \"US\", \"LY\", \"NI\", \"TT\", \"MK\", \"KZ\", \"BO\", \"UG\", \"TZ\", \"CL\", \"SI\", \"MA\", \"RW\", \"VN\", \"AW\", \"CY\", \"BH\", \"SG\", \"ZA\", \"MU\", \"BR\", \"TN\", \"KH\", \"US\", \"TH\", \"TW\", \"UY\", \"DO\", \"CO\", \"UA\", \"QA\", \"BY\", \"SN\", \"SD\", \"FJ\", \"LB\", \"BE\", \"ML\", \"LV\", \"FR\", \"TM\", \"NG\", \"EC\", \"NO\", \"SL\", \"CR\", \"PA\", \"GE\", \"CH\", \"KR\", \"RS\", \"ZM\", \"FI\", \"BF\", \"MC\", \"AU\", \"GA\", \"LS\", \"RU\", \"IN\", \"SE\", \"LK\", \"BZ\", \"MX\", \"GH\", \"AF\", \"TJ\", \"BN\", \"DZ\", \"CM\", \"GR\", \"MD\", \"HN\", \"AT\", \"NZ\", \"SV\", \"GW\", \"NA\", \"AR\", \"MZ\", \"PK\", \"MN\", \"IQ\", \"BW\", \"VE\", \"PT\", \"BS\", \"AL\", \"TG\", \"ID\", \"ET\", \"CF\", \"JP\", \"BB\", \"PH\", \"CU\", \"BD\", \"AO\", \"SM\", \"LC\", \"ME\", \"RO\",  DANIL\"O\"\", \"ES\", \"EE\", \"IL\", \"ZW\", \"SY\", \"MW\", \"LU\", \"IR\", \"SC\", \"NL\", \"JO\", \"AM\", \"DE\", \"GL\", \"OM\", \"DK\", \"HR\", \"LI\", \"TD\", \"KM\", \"BA\", \"GM\", \"GD\", \"CA\", \"CZ\", \"MR\", \"ST\", \"IS\", \"LR\", \"IE\", \"VC\", \"AE\", \"KG\", \"DJ\", \"TR\", \"KE\", \"NE\", \"UZ\", \"CN\", \"GQ\", \"SK\", \"BJ\", \"MG\", \"BT\", \"EG\", \"PL\", \"IT\", \"SA\", \"MY\", \"CI\", \"AG\", \"AD\", \"KS\", \"HU\", \"CG\", \"KP\", \"DM\", \"GN\", \"GT\", \"NP\", \"JM\", \"LA\", \"GB\", \"BG\", \"HT\", \"PE\", \"AZ\", \"LT\", \"SZ\", \"PY\", \"MT\", \"VA\"  # noqa: E501

        :param country_code: The country_code of this GetGenderRequest.  # noqa: E501
        :type: str
        """

        self._country_code = country_code

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetGenderRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetGenderRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    validateapi

    The validation APIs help you validate data. Check if an E-mail address is real. Check if a domain is real. Check up on an IP address, and even where it is located. All this and much more is available in the validation API.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class FullEmailValidationResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'valid_address': 'bool',
        'mail_server_used_for_validation': 'str',
        'valid_syntax': 'bool',
        'valid_domain': 'bool',
        'valid_smtp': 'bool',
        'is_catchall_domain': 'bool',
        'domain': 'str',
        'is_free_email_provider': 'bool',
        'is_disposable': 'bool'
    }

    attribute_map = {
        'valid_address': 'ValidAddress',
        'mail_server_used_for_validation': 'MailServerUsedForValidation',
        'valid_syntax': 'Valid_Syntax',
        'valid_domain': 'Valid_Domain',
        'valid_smtp': 'Valid_SMTP',
        'is_catchall_domain': 'IsCatchallDomain',
        'domain': 'Domain',
        'is_free_email_provider': 'IsFreeEmailProvider',
        'is_disposable': 'IsDisposable'
    }

    def __init__(self, valid_address=None, mail_server_used_for_validation=None, valid_syntax=None, valid_domain=None, valid_smtp=None, is_catchall_domain=None, domain=None, is_free_email_provider=None, is_disposable=None):  # noqa: E501
        """FullEmailValidationResponse - a model defined in Swagger"""  # noqa: E501

        self._valid_address = None
        self._mail_server_used_for_validation = None
        self._valid_syntax = None
        self._valid_domain = None
        self._valid_smtp = None
        self._is_catchall_domain = None
        self._domain = None
        self._is_free_email_provider = None
        self._is_disposable = None
        self.discriminator = None

        if valid_address is not None:
            self.valid_address = valid_address
        if mail_server_used_for_validation is not None:
            self.mail_server_used_for_validation = mail_server_used_for_validation
        if valid_syntax is not None:
            self.valid_syntax = valid_syntax
        if valid_domain is not None:
            self.valid_domain = valid_domain
        if valid_smtp is not None:
            self.valid_smtp = valid_smtp
        if is_catchall_domain is not None:
            self.is_catchall_domain = is_catchall_domain
        if domain is not None:
            self.domain = domain
        if is_free_email_provider is not None:
            self.is_free_email_provider = is_free_email_provider
        if is_disposable is not None:
            self.is_disposable = is_disposable

    @property
    def valid_address(self):
        """Gets the valid_address of this FullEmailValidationResponse.  # noqa: E501

        True if the email address is valid overall, false otherwise  # noqa: E501

        :return: The valid_address of this FullEmailValidationResponse.  # noqa: E501
        :rtype: bool
        """
        return self._valid_address

    @valid_address.setter
    def valid_address(self, valid_address):
        """Sets the valid_address of this FullEmailValidationResponse.

        True if the email address is valid overall, false otherwise  # noqa: E501

        :param valid_address: The valid_address of this FullEmailValidationResponse.  # noqa: E501
        :type: bool
        """

        self._valid_address = valid_address

    @property
    def mail_server_used_for_validation(self):
        """Gets the mail_server_used_for_validation of this FullEmailValidationResponse.  # noqa: E501

        Email server connected to for verification  # noqa: E501

        :return: The mail_server_used_for_validation of this FullEmailValidationResponse.  # noqa: E501
        :rtype: str
        """
        return self._mail_server_used_for_validation

    @mail_server_used_for_validation.setter
    def mail_server_used_for_validation(self, mail_server_used_for_validation):
        """Sets the mail_server_used_for_validation of this FullEmailValidationResponse.

        Email server connected to for verification  # noqa: E501

        :param mail_server_used_for_validation: The mail_server_used_for_validation of this FullEmailValidationResponse.  # noqa: E501
        :type: str
        """

        self._mail_server_used_for_validation = mail_server_used_for_validation

    @property
    def valid_syntax(self):
        """Gets the valid_syntax of this FullEmailValidationResponse.  # noqa: E501

        True if the syntax of the email address is valid, false otherwise.  This is one component of ValidAddress, but not the only one.  # noqa: E501

        :return: The valid_syntax of this FullEmailValidationResponse.  # noqa: E501
        :rtype: bool
        """
        return self._valid_syntax

    @valid_syntax.setter
    def valid_syntax(self, valid_syntax):
        """Sets the valid_syntax of this FullEmailValidationResponse.

        True if the syntax of the email address is valid, false otherwise.  This is one component of ValidAddress, but not the only one.  # noqa: E501

        :param valid_syntax: The valid_syntax of this FullEmailValidationResponse.  # noqa: E501
        :type: bool
        """

        self._valid_syntax = valid_syntax

    @property
    def valid_domain(self):
        """Gets the valid_domain of this FullEmailValidationResponse.  # noqa: E501

        True if the domain name of the email address is valid, false otherwise.  This is one component of ValidAddress, but not the only one.  # noqa: E501

        :return: The valid_domain of this FullEmailValidationResponse.  # noqa: E501
        :rtype: bool
        """
        return self._valid_domain

    @valid_domain.setter
    def valid_domain(self, valid_domain):
        """Sets the valid_domain of this FullEmailValidationResponse.

        True if the domain name of the email address is valid, false otherwise.  This is one component of ValidAddress, but not the only one.  # noqa: E501

        :param valid_domain: The valid_domain of this FullEmailValidationResponse.  # noqa: E501
        :type: bool
        """

        self._valid_domain = valid_domain

    @property
    def valid_smtp(self):
        """Gets the valid_smtp of this FullEmailValidationResponse.  # noqa: E501

        True if the email address was verified by the remote server, false otherwise.  This is one component of ValidAddress, but not the only one.  # noqa: E501

        :return: The valid_smtp of this FullEmailValidationResponse.  # noqa: E501
        :rtype: bool
        """
        return self._valid_smtp

    @valid_smtp.setter
    def valid_smtp(self, valid_smtp):
        """Sets the valid_smtp of this FullEmailValidationResponse.

        True if the email address was verified by the remote server, false otherwise.  This is one component of ValidAddress, but not the only one.  # noqa: E501

        :param valid_smtp: The valid_smtp of this FullEmailValidationResponse.  # noqa: E501
        :type: bool
        """

        self._valid_smtp = valid_smtp

    @property
    def is_catchall_domain(self):
        """Gets the is_catchall_domain of this FullEmailValidationResponse.  # noqa: E501

        True if the domain is a catch-all domain name, false otherwise.  Catch-all domain names, while rare, always accept inbound email to ensure they do not lose any potentially useful emails.  Catch-all domain names can occassionally be configured to first accept and store all inbound email, but then later send a bounce email back to the sender after a delayed period of time.  # noqa: E501

        :return: The is_catchall_domain of this FullEmailValidationResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_catchall_domain

    @is_catchall_domain.setter
    def is_catchall_domain(self, is_catchall_domain):
        """Sets the is_catchall_domain of this FullEmailValidationResponse.

        True if the domain is a catch-all domain name, false otherwise.  Catch-all domain names, while rare, always accept inbound email to ensure they do not lose any potentially useful emails.  Catch-all domain names can occassionally be configured to first accept and store all inbound email, but then later send a bounce email back to the sender after a delayed period of time.  # noqa: E501

        :param is_catchall_domain: The is_catchall_domain of this FullEmailValidationResponse.  # noqa: E501
        :type: bool
        """

        self._is_catchall_domain = is_catchall_domain

    @property
    def domain(self):
        """Gets the domain of this FullEmailValidationResponse.  # noqa: E501

        Domain name of the email address  # noqa: E501

        :return: The domain of this FullEmailValidationResponse.  # noqa: E501
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this FullEmailValidationResponse.

        Domain name of the email address  # noqa: E501

        :param domain: The domain of this FullEmailValidationResponse.  # noqa: E501
        :type: str
        """

        self._domain = domain

    @property
    def is_free_email_provider(self):
        """Gets the is_free_email_provider of this FullEmailValidationResponse.  # noqa: E501

        True if the email domain name is a free provider (typically a free to sign up web email provider for consumers / personal use), false otherwise.  # noqa: E501

        :return: The is_free_email_provider of this FullEmailValidationResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_free_email_provider

    @is_free_email_provider.setter
    def is_free_email_provider(self, is_free_email_provider):
        """Sets the is_free_email_provider of this FullEmailValidationResponse.

        True if the email domain name is a free provider (typically a free to sign up web email provider for consumers / personal use), false otherwise.  # noqa: E501

        :param is_free_email_provider: The is_free_email_provider of this FullEmailValidationResponse.  # noqa: E501
        :type: bool
        """

        self._is_free_email_provider = is_free_email_provider

    @property
    def is_disposable(self):
        """Gets the is_disposable of this FullEmailValidationResponse.  # noqa: E501

        True if the email address is a disposable email address, false otherwise; these disposable providers are not typically used to receive email and so will have a low likelihood of opening mail sent there.  # noqa: E501

        :return: The is_disposable of this FullEmailValidationResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_disposable

    @is_disposable.setter
    def is_disposable(self, is_disposable):
        """Sets the is_disposable of this FullEmailValidationResponse.

        True if the email address is a disposable email address, false otherwise; these disposable providers are not typically used to receive email and so will have a low likelihood of opening mail sent there.  # noqa: E501

        :param is_disposable: The is_disposable of this FullEmailValidationResponse.  # noqa: E501
        :type: bool
        """

        self._is_disposable = is_disposable

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FullEmailValidationResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FullEmailValidationResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    validateapi

    The validation APIs help you validate data. Check if an E-mail address is real. Check if a domain is real. Check up on an IP address, and even where it is located. All this and much more is available in the validation API.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class FullNameValidationResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'successful': 'bool',
        'validation_result_first_name': 'str',
        'validation_result_last_name': 'str',
        'title': 'str',
        'first_name': 'str',
        'middle_name': 'str',
        'last_name': 'str',
        'nick_name': 'str',
        'suffix': 'str',
        'display_name': 'str'
    }

    attribute_map = {
        'successful': 'Successful',
        'validation_result_first_name': 'ValidationResult_FirstName',
        'validation_result_last_name': 'ValidationResult_LastName',
        'title': 'Title',
        'first_name': 'FirstName',
        'middle_name': 'MiddleName',
        'last_name': 'LastName',
        'nick_name': 'NickName',
        'suffix': 'Suffix',
        'display_name': 'DisplayName'
    }

    def __init__(self, successful=None, validation_result_first_name=None, validation_result_last_name=None, title=None, first_name=None, middle_name=None, last_name=None, nick_name=None, suffix=None, display_name=None):  # noqa: E501
        """FullNameValidationResponse - a model defined in Swagger"""  # noqa: E501

        self._successful = None
        self._validation_result_first_name = None
        self._validation_result_last_name = None
        self._title = None
        self._first_name = None
        self._middle_name = None
        self._last_name = None
        self._nick_name = None
        self._suffix = None
        self._display_name = None
        self.discriminator = None

        if successful is not None:
            self.successful = successful
        if validation_result_first_name is not None:
            self.validation_result_first_name = validation_result_first_name
        if validation_result_last_name is not None:
            self.validation_result_last_name = validation_result_last_name
        if title is not None:
            self.title = title
        if first_name is not None:
            self.first_name = first_name
        if middle_name is not None:
            self.middle_name = middle_name
        if last_name is not None:
            self.last_name = last_name
        if nick_name is not None:
            self.nick_name = nick_name
        if suffix is not None:
            self.suffix = suffix
        if display_name is not None:
            self.display_name = display_name

    @property
    def successful(self):
        """Gets the successful of this FullNameValidationResponse.  # noqa: E501

        True if the validation operation was successful, false otherwise  # noqa: E501

        :return: The successful of this FullNameValidationResponse.  # noqa: E501
        :rtype: bool
        """
        return self._successful

    @successful.setter
    def successful(self, successful):
        """Sets the successful of this FullNameValidationResponse.

        True if the validation operation was successful, false otherwise  # noqa: E501

        :param successful: The successful of this FullNameValidationResponse.  # noqa: E501
        :type: bool
        """

        self._successful = successful

    @property
    def validation_result_first_name(self):
        """Gets the validation_result_first_name of this FullNameValidationResponse.  # noqa: E501

        Possible values are: ValidFirstName, ValidUnknownFirstName, InvalidSpamInput, InvalidCharacters, InvalidEmpty  # noqa: E501

        :return: The validation_result_first_name of this FullNameValidationResponse.  # noqa: E501
        :rtype: str
        """
        return self._validation_result_first_name

    @validation_result_first_name.setter
    def validation_result_first_name(self, validation_result_first_name):
        """Sets the validation_result_first_name of this FullNameValidationResponse.

        Possible values are: ValidFirstName, ValidUnknownFirstName, InvalidSpamInput, InvalidCharacters, InvalidEmpty  # noqa: E501

        :param validation_result_first_name: The validation_result_first_name of this FullNameValidationResponse.  # noqa: E501
        :type: str
        """

        self._validation_result_first_name = validation_result_first_name

    @property
    def validation_result_last_name(self):
        """Gets the validation_result_last_name of this FullNameValidationResponse.  # noqa: E501

        Possible values are: ValidLastName, ValidUnknownLastName, InvalidSpamInput, InvalidCharacters, InvalidEmpty  # noqa: E501

        :return: The validation_result_last_name of this FullNameValidationResponse.  # noqa: E501
        :rtype: str
        """
        return self._validation_result_last_name

    @validation_result_last_name.setter
    def validation_result_last_name(self, validation_result_last_name):
        """Sets the validation_result_last_name of this FullNameValidationResponse.

        Possible values are: ValidLastName, ValidUnknownLastName, InvalidSpamInput, InvalidCharacters, InvalidEmpty  # noqa: E501

        :param validation_result_last_name: The validation_result_last_name of this FullNameValidationResponse.  # noqa: E501
        :type: str
        """

        self._validation_result_last_name = validation_result_last_name

    @property
    def title(self):
        """Gets the title of this FullNameValidationResponse.  # noqa: E501

        The person's title (if supplied), e.g. \"Mr.\" or \"Ms.\"  # noqa: E501

        :return: The title of this FullNameValidationResponse.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this FullNameValidationResponse.

        The person's title (if supplied), e.g. \"Mr.\" or \"Ms.\"  # noqa: E501

        :param title: The title of this FullNameValidationResponse.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def first_name(self):
        """Gets the first_name of this FullNameValidationResponse.  # noqa: E501

        The first name (given name)  # noqa: E501

        :return: The first_name of this FullNameValidationResponse.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this FullNameValidationResponse.

        The first name (given name)  # noqa: E501

        :param first_name: The first_name of this FullNameValidationResponse.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def middle_name(self):
        """Gets the middle_name of this FullNameValidationResponse.  # noqa: E501

        The middle name(s); if there are multiple names they will be separated by spaces  # noqa: E501

        :return: The middle_name of this FullNameValidationResponse.  # noqa: E501
        :rtype: str
        """
        return self._middle_name

    @middle_name.setter
    def middle_name(self, middle_name):
        """Sets the middle_name of this FullNameValidationResponse.

        The middle name(s); if there are multiple names they will be separated by spaces  # noqa: E501

        :param middle_name: The middle_name of this FullNameValidationResponse.  # noqa: E501
        :type: str
        """

        self._middle_name = middle_name

    @property
    def last_name(self):
        """Gets the last_name of this FullNameValidationResponse.  # noqa: E501

        The last name (surname)  # noqa: E501

        :return: The last_name of this FullNameValidationResponse.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this FullNameValidationResponse.

        The last name (surname)  # noqa: E501

        :param last_name: The last_name of this FullNameValidationResponse.  # noqa: E501
        :type: str
        """

        self._last_name = last_name

    @property
    def nick_name(self):
        """Gets the nick_name of this FullNameValidationResponse.  # noqa: E501

        Nickname (if supplied)  # noqa: E501

        :return: The nick_name of this FullNameValidationResponse.  # noqa: E501
        :rtype: str
        """
        return self._nick_name

    @nick_name.setter
    def nick_name(self, nick_name):
        """Sets the nick_name of this FullNameValidationResponse.

        Nickname (if supplied)  # noqa: E501

        :param nick_name: The nick_name of this FullNameValidationResponse.  # noqa: E501
        :type: str
        """

        self._nick_name = nick_name

    @property
    def suffix(self):
        """Gets the suffix of this FullNameValidationResponse.  # noqa: E501

        Suffix to the name, e.g. \"Jr.\" or \"Sr.\"  # noqa: E501

        :return: The suffix of this FullNameValidationResponse.  # noqa: E501
        :rtype: str
        """
        return self._suffix

    @suffix.setter
    def suffix(self, suffix):
        """Sets the suffix of this FullNameValidationResponse.

        Suffix to the name, e.g. \"Jr.\" or \"Sr.\"  # noqa: E501

        :param suffix: The suffix of this FullNameValidationResponse.  # noqa: E501
        :type: str
        """

        self._suffix = suffix

    @property
    def display_name(self):
        """Gets the display_name of this FullNameValidationResponse.  # noqa: E501

        The full display name of the name  # noqa: E501

        :return: The display_name of this FullNameValidationResponse.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this FullNameValidationResponse.

        The full display name of the name  # noqa: E501

        :param display_name: The display_name of this FullNameValidationResponse.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FullNameValidationResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FullNameValidationResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
